@@ -10,7 +10,7 @@ import logging
 
 
 # Global vars
-_LOGGER: logging.Logger
+_LOGGER: logging.Logger = None
 
 
 def init_logger(debug: bool) -> None:
@@ -30,4 +30,6 @@ def init_logger(debug: bool) -> None:
 
 
 def get_logger() -> logging.Logger:
+    if not _LOGGER:
+        init_logger(True)
     return _LOGGER
